"""
Package root.
"""


# Directly import submodules
from . import aa, junction, mhc, tcr
